# InitCommerce Common Utilities

This project includes common libraries and utilities to avoid depending on
third party libraries. It aims to increase the abstraction by providing the
dependencies through a layer that can be evolved without hassle.
